@@ -24,7 +24,7 @@ sub component_base_class { 'DBIx::Class' }
 # i.e. first release of 0.XX *must* be 0.XX000. This avoids fBSD ports
 # brain damage and presumably various other packaging systems too
 
-$VERSION = '0.08100';
+$VERSION = '0.08101';
 
 $VERSION = eval $VERSION; # numify for warning-free dev releases
 
@@ -207,6 +207,8 @@ andyg: Andy Grundman <andy@hybridized.org>
 
 ank: Andres Kievsky
 
+arcanez: Justin Hunter <justin.d.hunter@gmail.com>
+
 ash: Ash Berlin <ash@cpan.org>
 
 bert: Norbert Csongradi <bert@cpan.org>
@@ -283,7 +285,7 @@ penguin: K J Cheetham
 
 perigrin: Chris Prather <chris@prather.org>
 
-Peter Collingbourne <peter@pcc.me.uk>
+peter: Peter Collingbourne <peter@pcc.me.uk>
 
 phaylon: Robert Sedlacek <phaylon@dunkelheit.at>
 
